@@ -464,7 +464,7 @@ class PanCtl:
     def sas_done(self, pan_user, user_id, device_id, _):
         print(
             f"Device {device_id} of user {user_id}"
-            f" succesfully verified for pan user {pan_user}."
+            f" successfully verified for pan user {pan_user}."
         )
 
     def show_sas_invite(self, pan_user, user_id, device_id, _):
@@ -695,7 +695,7 @@ class PanCtl:
         "the pantalaimon daemon."
     )
 )
-@click.version_option(version="0.10.4", prog_name="panctl")
+@click.version_option(version="0.10.5", prog_name="panctl")
 def main():
     loop = asyncio.new_event_loop()
     glib_loop = GLib.MainLoop()
